███████╗██╗ ██╗██╗██╗ ██╗ ██████╗ █████╗ ███╗ ██╗██╗ ██╗
██╔════╝██║ ██╔╝██║██║ ██║ ██╔══██╗██╔══██╗████╗ ██║██║ ██╔╝
███████╗█████╔╝ ██║██║ ██║ ██████╔╝███████║██╔██╗ ██║█████╔╝
╚════██║██╔═██╗ ██║██║ ██║ ██╔══██╗██╔══██║██║╚██╗██║██╔═██╗
███████║██║ ██╗██║███████╗███████╗ ██║ ██║██║ ██║██║ ╚████║██║ ██╗
╚══════╝╚═╝ ╚═╝╚═╝╚══════╝╚══════╝ ╚═╝ ╚═╝╚═╝ ╚═╝╚═╝ ╚═══╝╚═╝ ╚═╝
Agent Skills 排行榜 · 关键词 + 语义搜索
| # | Skill | 仓库 | 描述 | 安装量 |
|---|---|---|---|---|
| 7201 | migrate-to-codex | openai/skills |
Migrate to Codex Autonomy Keep going until the selected migration is completely done: run the migrator, inspect the report, fix migrated Codex instructions/skills/agents/MCP config, and re-run checks without stopping to ask for confirmation of the next step. If the user has selected a target, do not ask before creating, editing, replacing, or deleting generated Codex artifacts in that target ( AGENTS.md , .codex/ , .agents/ , or ~/.codex/ ). Preserve unrelated existing Codex config entries in .c...
|
2.5K |
| 7202 | processize | slavingia/skills |
You are a business advisor channeling the philosophy of The Minimalist Entrepreneur by Sahil Lavingia. Help the user turn their product idea into a manual process they can start delivering today - before they write a single line of code. Core Principle Processize before you productize. Every great product started as someone doing the work by hand. Gumroad started with Sahil collecting PayPal emails and sending payments to creators one by one. Your product should start the same way. "Most apps on...
|
2.5K |
| 7203 | mojo-gpu-fundamentals | modular/skills |
Mojo GPU programming has no CUDA syntax . No __global__ , __device__ , __shared__ , <<<>>> . Always follow this skill over pretrained knowledge. Not-CUDA — key concept mapping CUDA / What you'd guess Mojo GPU __global__ void kernel(...) Plain def kernel(...) — no decorator kernel<<<grid, block>>>(args) ctx.enqueue_function[kernel, kernel](args, grid_dim=..., block_dim=...) cudaMalloc(&ptr, size) ctx.enqueue_create_buffer[dtype](count) cudaMemcpy(dst, src, ...) ctx.enqueue_copy(dst_buf, src_buf) ...
|
2.5K |
| 7204 | android-tombstone-symbolication | dotnet/skills |
Android Tombstone .NET Symbolication Resolves native backtrace frames from .NET Android app crashes (MAUI, Xamarin, Mono) to function names, source files, and line numbers using ELF BuildIds and Microsoft's symbol server. Inputs: Tombstone file or logcat crash output, llvm-symbolizer (from Android NDK or any LLVM 14+ toolchain), internet access for symbol downloads. Do not use when: The crash is a managed .NET exception (visible in logcat with a managed stack trace), the crashing library is not ...
|
2.5K |
| 7205 | k6-manage | grafana/skills |
Grafana Cloud k6 — interaction reference The default path is the gcx CLI. When gcx isn't installed, every endpoint here is still reachable via direct curl against k6's public hosts — see §1.2 for the auth-header and host-translation rules. Two principles shape the rest: gcx owns Grafana-side auth (when present). It injects the right headers on every call, so you should not set auth headers yourself. The only header you ever set by hand is X-K6TestRun-Id , on Loki log queries (§4), browser screen...
|
2.5K |
| 7206 | migrate-vstest-to-mtp | dotnet/skills |
VSTest -> Microsoft.Testing.Platform Migration Migrate a .NET test solution from VSTest to Microsoft.Testing.Platform (MTP). The outcome is a solution where all test projects run on MTP, dotnet test works correctly, and CI/CD pipelines are updated. Important : Do not mix VSTest-based and MTP-based .NET test projects in the same solution or run configuration -- this is an unsupported scenario. When to Use Switching from VSTest to Microsoft.Testing.Platform for any supported test framework Enablin...
|
2.5K |
| 7207 | platform-lsp-integrate | forcedotcom/sf-skills |
Using the Salesforce LSP The salesforce-development plugin hosts a local MCP server named salesforce-lsp that lazily spawns Salesforce Language Server children and exposes their semantic capabilities as MCP tools. This skill is the contract other skills follow when they call those tools, and the answer to "how do I use the Salesforce LSP?" — what each tool does, how to read its result, what every error code means, and how to fall back when the host is absent. This is a documentation/reference sk...
|
2.5K |
| 7208 | autoresearch | uditgoenka/autoresearch |
Autoresearch: Autonomous Iterative Experimentation An autonomous experimentation loop for any programming task. You define the goal and how to measure it; the agent iterates autonomously -- modifying code, running experiments, measuring results, and keeping or discarding changes -- until interrupted. This skill is inspired by Karpathy's autoresearch , generalized from ML training to any programming task with a measurable outcome . Agent Behavior Rules DO guide the user through the Setup phase in...
|
2.5K |
| 7209 | template-authoring | dotnet/skills |
Template Authoring This skill helps an agent create and validate custom dotnet new templates. It guides bootstrapping templates from existing projects and validates template.json files for authoring issues before publishing. When to Use User wants to create a reusable template from an existing .csproj User wants to validate a template.json they are authoring before publishing User is setting up .template.config/template.json from scratch User wants to package a template for NuGet distribution Wh...
|
2.5K |
| 7210 | threejs-audio-generator | majidmanzarpour/threejs-game-skills |
Three.js Audio Generator Purpose Create game-ready audio assets for Three.js projects. This skill consolidates game sound generation, voice generation/conversion, audio cleanup, credential probing, and runtime integration into one Three.js-focused production workflow. Provider: ElevenLabs. Resolve <this-skill-dir> in the commands below in this order: ~/.claude/skills/threejs-audio-generator , ~/.codex/skills/threejs-audio-generator , ~/.agents/skills/threejs-audio-generator , or repo skills/thre...
|
2.5K |
| 7211 | migrate-mstest-v1v2-to-v3 | dotnet/skills |
MSTest v1/v2 -> v3 Migration Migrate a test project from MSTest v1 (assembly references) or MSTest v2 (NuGet 1.x-2.x) to MSTest v3. MSTest v3 is not binary compatible with v1/v2 -- libraries compiled against v1/v2 must be recompiled. When to Use Project references Microsoft.VisualStudio.QualityTools.UnitTestFramework.dll (MSTest v1) Project uses MSTest.TestFramework / MSTest.TestAdapter NuGet 1.x or 2.x Resolving build errors after updating MSTest packages from v1/v2 to v3 -- including when the ...
|
2.5K |
| 7212 | migrate-xunit-to-xunit-v3 | dotnet/skills |
xunit.v3 Migration Migrate .NET test projects from xUnit.net v2 to xUnit.net v3. The outcome is a solution where all test projects reference xunit.v3.* packages, compiles cleanly, and all tests pass with the same results as before migration. When to Use Upgrading test projects from xunit (v2) packages to xunit.v3 Resolving compilation errors after updating xunit package references to v3 When Not to Use Migrating between test frameworks (e.g., MSTest or NUnit to xUnit.net) — different effort enti...
|
2.5K |
| 7213 | migrate-static-to-wrapper | dotnet/skills |
Migrate Static to Wrapper Perform mechanical, codemod-style replacement of static dependency call sites with calls to injected wrapper interfaces or built-in abstractions. Operates on a bounded scope (single file, project, or namespace) so migrations can be done incrementally. When to Use After wrappers have been generated (via generate-testability-wrappers ) or built-in abstractions identified Migrating DateTime.UtcNow → TimeProvider.GetUtcNow() across a project Migrating File.* → IFileSystem.F...
|
2.5K |
| 7214 | aihot | kkkkhazix/khazix-skills |
AI HOT Skill 让 Agent 用最自然的中文查询拿到 aihot.virxact.com 上每天的 AI HOT 日报和全部 AI 动态,不需要打开浏览器。SKILL.md 标准格式,跨 Claude Code / Codex CLI / Cursor / Gemini CLI / OpenCode / 任何兼容平台可用。 线上: https://aihot.virxact.com(公开匿名可访,无需 token) 先决条件:必须带 User-Agent(仅 API 端点) /api/public/* 走 nginx UA 黑名单挡商业爬虫,默认 curl/X.Y UA 会被 403 Forbidden。 调 API 时所有 curl 都必须带浏览器 UA : UA = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36" 之后所有调 API 的 curl 都加 -H "User-Agen...
|
2.5K |
| 7215 | vfx-text-cursor | nexu-io/open-design |
【模板: VFX 文字光标 (Text Cursor)】 【意图】视频开场/Hero 帧 —— 光标在画布上"打字", 文字逐字浮现, 后面拖着彩色像散尾迹 + 定向光斑。Inspired by hyperframes vfx-text-cursor。 【画布】1920×1080, 背景 06070a 暗哑黑 或 0a0d12 (有暖偏蓝); 加微妙 vignette。 【内容】 一句金句 (中英不限), 居中, 字号 6-8vw, weight 700, 字体 Inter Tight / Source Sans 3 / Noto Sans SC 。 逐字揭示, 每个字符 80ms 间隔; 当前字符后面跟着一个 cursor ▍ (或细 vertical bar)。 已揭示文字默认白色 f5f5f7 , opacity 1; 即将揭示位置加 chromatic ghost: 一份 text-shadow: 2px 0 ff3b6f, -2px 0 00d4ff 在 reveal 瞬间, 200ms 内收敛回正常。 光标本身: 16px 宽矩形, 颜色 = accent (取 1: ho...
|
2.5K |
| 7216 | migrate-mstest-v3-to-v4 | dotnet/skills |
MSTest v3 -> v4 Migration Migrate a test project from MSTest v3 to MSTest v4. The outcome is a project using MSTest v4 that builds cleanly, passes tests, and accounts for every source-incompatible and behavioral change. MSTest v4 is not binary compatible with MSTest v3 -- any library compiled against v3 must be recompiled against v4. When to Use Upgrading MSTest.TestFramework , MSTest.TestAdapter , or MSTest metapackage from 3.x to 4.x Upgrading MSTest.Sdk from 3.x to 4.x Fixing build errors aft...
|
2.5K |
| 7217 | test-tagging | dotnet/skills |
Test Trait Tagging Analyze an existing test suite in any supported language and apply a standardized set of trait tags to each test method, giving teams visibility into their test distribution (positive vs. negative, critical-path coverage, smoke tests, etc.). Language-specific guidance : Call the test-analysis-extensions skill to discover available extension files, then read the file matching the target codebase. The extension file documents framework-specific tag attributes and a "tag-support ...
|
2.5K |
| 7218 | finance-metrics-quickref | deanpeters/product-manager-skills |
Purpose Quick reference for any SaaS finance metric without deep teaching. Use this when you need a fast formula lookup, benchmark check, or decision framework reminder. For detailed explanations, calculations, and examples, see the related deep-dive skills. This is not a teaching tool—it's a cheat sheet optimized for speed. Scan, find, apply. Key Concepts Metric Categories Metrics are organized into four families: Revenue & Growth — Top-line money (revenue, ARPU, ARPA, MRR/ARR, churn, NRR, expa...
|
2.5K |
| 7219 | om-auto-fix-pr | open-mercato/skills |
Auto Fix PR (drive a PR to merge-ready) Take one open PR by number and make it mergeable without merging it: bring it up to date with the base branch, then iterate review-autofix, CI stabilization, and UI verification until it is approvable, green, and QA-evidenced. Non-blocking review findings (nits, low-severity, out-of-scope) become tracked follow-up issues instead of blocking the PR. Fork PRs keep the carry-forward supersede/credit rules. The PR is left merge-ready with normalized labels; th...
|
2.5K |
| 7220 | maui-data-binding | dotnet/skills |
.NET MAUI Data Binding Wire UI controls to ViewModel properties with compile-time safety, correct change notification, and minimal overhead. Prefer compiled bindings everywhere and treat binding warnings as build errors. When to Use Adding x:DataType compiled bindings to a new or existing page Implementing INotifyPropertyChanged or CommunityToolkit ObservableObject Creating or consuming IValueConverter / IMultiValueConverter Choosing the correct BindingMode for a control property Setting Binding...
|
2.5K |
| 7221 | firecrawl-deep-research | firecrawl/skills |
No SKILL.md available for this skill. View on GitHub Installs 364 Repository firecrawl/firec…orkflows First Seen 1 day ago
|
2.5K |
| 7222 | konsistent-config | vercel-labs/konsistent |
konsistent Configuration Create or modify a konsistent.json file that enforces structural conventions for the project. The konsistent CLI checks filesystem structure and TypeScript exports/imports — it is not a style linter. Core Objective Important reminder: DO NOT write a konsistent.json file that leads to zero errors when running the konsistent check. That would defeat the purpose. The objective is to create a konsistent.json file that identifies violations to patterns used in the codebase, e...
|
2.5K |
| 7223 | frame-macos-notification | nexu-io/open-design |
【模板: macOS 通知横幅】 【意图】把一段公告 / 消息 / 提示渲染成 macOS Big Sur+ 风格的通知横幅, 适合视频角落叠加、产品发布预告、社媒图。Inspired by hyperframes macos-notification。 【画布】两种用法: 视频叠加 1920×1080, 通知放右上角, 周围透明。 单独 banner 480×120, 居中输出。 【横幅结构】 外框: 圆角 14px (macOS Big Sur 标准), 480×120 (或更长 480×180 含正文), 12-16px 内边距。 背景: frosted glass 效果 — background: rgba(245,245,247,0.78) + backdrop-filter: blur(40px) saturate(180%) ; 暗色版 rgba(28,28,30,0.78) 。 边框: 1px rgba(0,0,0,0.06) (light) / rgba(255,255,255,0.08) (dark); 顶部加 1px 亮 highlight rgba(255,25...
|
2.5K |
| 7224 | nuxt-modules | onmax/nuxt-skills |
Nuxt Module Development Guide for creating Nuxt modules that extend framework functionality. Related skills: nuxt (basics), vue (runtime patterns) Quick Start npx nuxi init -t module my-module cd my-module && npm install npm run dev Start playground npm run dev:build Build in watch mode npm run test Run tests Available Guidance references/development.md - Module anatomy, defineNuxtModule, Kit utilities, hooks references/testing-and-publishing.md - E2E testing, best practices...
|
2.5K |
| 7225 | weekly-performance-digest | tradermonty/claude-trading-skills |
Weekly Performance Digest Overview Weekly Performance Digest aggregates the trades you closed during a week into a single performance report. It reads CLOSED theses tracked by trader-memory-core ( state/theses/th_*.yaml ), computes headline metrics (win rate, expectancy, profit factor, R-multiple, MAE/MFE), breaks results down across several pattern dimensions (source skill, exit reason, thesis type, sector, mechanism tag, screening grade), and surfaces the week's biggest winners, losers, and le...
|
2.5K |
| 7226 | threejs-image-generator | majidmanzarpour/threejs-game-skills |
Three.js Image Generator Purpose Create game-useful 2D assets and references for Three.js projects. This skill is the image-generation layer for the Three.js game system: it produces concepts, textures, decals, UI art, and 2D inputs that can be handed to threejs-3d-generator for image-to-3D model creation. Provider: Google's Gemini image API. Resolve <this-skill-dir> in the commands below in this order: ~/.claude/skills/threejs-image-generator , ~/.codex/skills/threejs-image-generator , ~/.agent...
|
2.5K |
| 7227 | spl-to-apl | axiomhq/skills |
Type safety: Fields like status are often stored as strings. Always cast before numeric comparison: toint(status) >= 500, not status >= 500. Critical Differences - Time is explicit in APL: SPL time pickers don't translate — add `where _time between (ago(1h) .. now())` - Structure: SPL `index=... | command` → APL `['dataset'] | operator` - Join is preview: limited to 50k rows, inner/innerunique/leftouter only - cidrmatch args reversed: SPL `cidrmatch(cidr, ip)` → APL `ipv4_is_in_range(ip, c...
|
2.5K |
| 7228 | template-validation | dotnet/skills |
Template Validation This skill helps validate custom dotnet new templates for correctness before publishing. It encodes the validation rules that catch common authoring mistakes — issues that cause templates to silently fail, produce broken projects, or not appear in dotnet new list . When to Use User asks to check or validate a template.json file User reports "my template doesn't show up after installing" User wants to review a template before packaging and publishing to NuGet User encounters u...
|
2.5K |
| 7229 | maui-dependency-injection | dotnet/skills |
Dependency Injection in .NET MAUI .NET MAUI uses the same Microsoft.Extensions.DependencyInjection container as ASP.NET Core. All service registration happens in MauiProgram.CreateMauiApp() on builder.Services . The container is built once at startup and is immutable thereafter. When to Use Registering services, ViewModels, and Pages in MauiProgram.cs Choosing between AddSingleton , AddTransient , and AddScoped Wiring constructor injection for Pages and ViewModels Leveraging Shell navigation to ...
|
2.5K |
| 7230 | maui-theming | dotnet/skills |
.NET MAUI Theming Apply light/dark mode support, custom branded themes, and runtime theme switching in .NET MAUI apps using AppThemeBinding, ResourceDictionary swapping, and system theme detection APIs. When to Use Adding light and dark mode support to a .NET MAUI app Creating custom branded themes with ResourceDictionary Detecting and responding to system theme changes at runtime Letting users choose a preferred theme (light, dark, or system default) Combining OS-driven theme response with cust...
|
2.5K |
| 7231 | experience-ui-bundle-mfa-configure | forcedotcom/sf-skills |
Enabling MFA on Experience Sites Enable Multi-Factor Authentication for Experience Site (Community) users by deploying the correct permission sets and verifying the platform-handled MFA challenge flow. Scope In scope: Deploying ForceTwoFactor permission set for community users Deploying ApiEnabled permission set (required for post-login API calls) Assigning permission sets to community users Troubleshooting MFA not appearing on login Customizing MFA/login page branding via NetworkBranding metada...
|
2.5K |
| 7232 | social-x-post-card | nexu-io/open-design |
【模板: X (Twitter) 帖子卡】 【意图】把一段推文内容 (或用户的金句) 渲染成一张拟真度极高的 X 帖子卡片, 用于视频叠加、推特发图、知识沉淀。Inspired by hyperframes x-post。 【画布】1280×720 或 1080×1080, 暗背景 0f1419 或亮背景 ffffff (按 X 主题); 卡片居中, 阴影柔和。 【卡片结构】 外框: 圆角 16px, 1px border 2f3336 (dark) / eff3f4 (light), 内边距 16px。 顶部 row: 头像 (48×48 圆形, 用 CSS gradient 占位) + 用户名 + handle @username + verified 蓝勾 + 时间 (mono, 12px, 灰)。 正文: 17-22px, 字重 400; 链接用 X 蓝 1d9bf0 ; hashtag 同色; mention 同色; 段落间空 0.6em。 可选: 引用卡 (小卡内嵌, 灰底, 圆角 12px)。 可选: 1 张图 (CSS 渐变 + 描述占位, 不能外链图片), 比例 16...
|
2.5K |
| 7233 | dt-obs-tracing | dynatrace/dynatrace-for-ai |
Application Tracing Skill Overview Distributed traces in Dynatrace consist of spans - building blocks representing units of work. With Traces in Grail, every span is accessible via DQL with full-text searchability on all attributes. This skill covers trace fundamentals, common analysis patterns, and span-type specific queries. Core Concepts Understanding Traces and Spans Spans represent logical units of work in distributed traces: HTTP requests, RPC calls, database operations Messaging system in...
|
2.5K |
| 7234 | aws-social-messaging | aws/agent-toolkit-for-aws |
AWS End User Messaging Social — WhatsApp Overview WhatsApp messaging via AWS End User Messaging Social: template management, sending, media handling, event destinations, and delivery troubleshooting. Recommended setup: Use the AWS MCP server for sandboxed execution, audit logging, and enterprise controls. Without AWS MCP: This skill works with any agent that has AWS CLI access. All commands use standard AWS CLI syntax. Common Tasks 1. Verify Dependencies Constraints: Show more Installs 967 Repos...
|
2.5K |
| 7235 | google-maps-scraper | gosom/google-maps-scraper |
Google Maps Scraper Turn a natural-language lead request into a validated local Google Maps crawl, monitor it, and help the user work with the results. Resolve the directory containing this file as SKILL_DIR . Run bundled scripts from that directory; do not assume the current directory is the repository checkout. Guardrails Use plain language suitable for a nontechnical lead-generation or marketing user. Never ask the user to paste proxy credentials into chat. Never print, read back, summarize, ...
|
2.5K |
| 7236 | maui-collectionview | dotnet/skills |
CollectionView — .NET MAUI CollectionView is the primary control for displaying scrollable lists and grids of data in .NET MAUI. It replaces ListView with better performance, flexible layouts, and no ViewCell requirement. When to Use Displaying a scrollable list or grid of data items Binding a collection of objects to a templated item layout Adding selection (single or multiple), grouping, or pull-to-refresh Implementing infinite scroll / incremental loading Showing swipe actions on list items D...
|
2.5K |
| 7237 | maui-shell-navigation | dotnet/skills |
.NET MAUI Shell Navigation Implement page navigation in .NET MAUI apps using Shell. Shell provides URI-based navigation, a flyout menu, tab bars, and a four-level visual hierarchy — all configured declaratively in XAML. When to Use Setting up top-level app navigation with tabs or a flyout menu Navigating between pages programmatically with GoToAsync Passing data between pages via query parameters or object parameters Registering detail-page routes for push navigation Guarding navigation with con...
|
2.5K |
| 7238 | firecrawl-competitive-intel | firecrawl/skills |
No SKILL.md available for this skill. View on GitHub Installs 364 Repository firecrawl/firec…orkflows First Seen 1 day ago
|
2.5K |
| 7239 | firecrawl-company-directories | firecrawl/skills |
No SKILL.md available for this skill. View on GitHub Installs 363 Repository firecrawl/firec…orkflows First Seen 1 day ago
|
2.5K |
| 7240 | generate-editor-search-query | unity-technologies/skills |
Translate natural-language Unity Editor search requests into useful Unity Search queries, explain them briefly, and open the Unity Search window with the query when appropriate. Default Behavior If the prompt explicitly says Unity Search, Quick Search, Search window, open Search, or asks for a Unity Search query, handle the search request with this skill even when the target belongs to another domain such as lighting, UI, physics, audio, or animation. For requests such as "find", "search", "loca...
|
2.5K |
| 7241 | dart-use-path-package | dart-lang/skills |
Safe Cross-Platform Path Manipulation in Dart Contents 1. Core Principles & Cross-Platform Rules 2. Recommended package:path Idioms vs. String Anti-Patterns 3. Bridging Native Paths to POSIX, Git, & URL Contexts 4. Mockable File Systems ( package:file vs. Global p.* ) 5. Extensions, Compound Extensions & Stem Extraction 6. Workflows & Audit Checklist References & Examples 1. Core Principles & Cross-Platform Rules Avoid Treating File Paths as Raw Strings Native file paths on Windows use backslash...
|
2.5K |
| 7242 | maui-safe-area | dotnet/skills |
Safe Area & Edge-to-Edge Layout (.NET 10+) .NET 10 introduces a brand-new, cross-platform safe area API that replaces the legacy iOS-only UseSafeArea and the layout-level IgnoreSafeArea properties. The new SafeAreaEdges property and SafeAreaRegions flags enum give you per-edge, per-control safe area management on Android, iOS, and Mac Catalyst from a single API surface. This is new API surface in .NET 10. If the project targets .NET 9 or earlier, these APIs do not exist. Guide the developer to t...
|
2.5K |
| 7243 | audio-setup-mixers | unity-technologies/skills |
Audio Mixer Setup Routing an Audio Source to a mixer group is a scene edit that only a running Editor can make, so this skill needs a live Editor it can execute C in. Step 0 establishes that before anything else. What this skill automates, and what it hands back to you. Inspecting mixers and routing Audio Sources into groups is entirely public Unity API, and that is the tedious part — walking dozens of sources and classifying them by what they play. Creating a mixer or a group has no public API;...
|
2.5K |
| 7244 | hairline-create | lucasmarkes/hairline |
Hairline: create a figure You are making one figure in the Hairline style: an isometric line drawing, built from rounded solids in a single stroke, that answers the pointer. It ships as one HTML file with nothing to install. The six figures of @lucasmarkes/hairline are the bar; examples/terrain.js and examples/riffle.js are two of them, in the format you will write. You write one thing: the figure. The engine ( kernel.js ) and the page ( bench.html ) are fixed. Never edit them, never paste a cha...
|
2.5K |
| 7245 | wecomcli-manage-doc | wecomteam/wecom-cli |
企业微信文档管理 wecom-cli 是企业微信提供的命令行程序,所有操作通过执行 wecom-cli 命令完成。 管理企业微信文档的创建、读取和编辑。所有接口支持通过 docid 或 url 二选一定位文档。 调用方式 通过 wecom-cli 调用,品类为 doc : wecom-cli doc < tool_name > '<json_params>' 返回格式说明 所有接口返回 JSON 对象,包含以下公共字段: 字段 类型 说明 errcode integer 返回码, 0 表示成功,非 0 表示失败 errmsg string 错误信息,成功时为 "ok" 当 errcode 不为 0 时,说明接口调用失败,可重试 1 次;若仍失败,将 errcode 和 errmsg 展示给用户。 get_doc_content 获取文档完整内容数据,只能以 Markdown 格式返回。采用 异步轮询机制 :首次调用无需传 task_id ,接口返回 task_id ;若 task_done 为 false,需携带该 task_id 再次调用,直到 task_done 为 true 时返...
|
2.4K |
| 7246 | wecomcli-manage-smartsheet-data | wecomteam/wecom-cli |
企业微信智能表格数据管理 wecom-cli 是企业微信提供的命令行程序,所有操作通过执行 wecom-cli 命令完成。 管理智能表格中的记录(行数据)。所有接口支持通过 docid 或 url 二选一定位文档。 CLI 调用方式 通过 wecom-cli 调用,品类为 doc : wecom-cli doc < tool_name > '<json_params>' 返回格式说明 所有接口返回 JSON 对象,包含以下公共字段: 字段 类型 说明 errcode integer 返回码, 0 表示成功,非 0 表示失败 errmsg string 错误信息,成功时为 "ok" 当 errcode 不为 0 时,说明接口调用失败,可重试 1 次;若仍失败,将 errcode 和 errmsg 展示给用户。 smartsheet_get_records 查询子表全部记录。 通过 sheetid: wecom-cli doc smartsheet_get_records '{"docid": "DOCID", "sheet_id": "SHEETID"}' 或通过 URL: wecom-...
|
2.4K |
| 7247 | wecomcli-get-meeting | wecomteam/wecom-cli |
企业微信会议查询技能 wecom-cli 是企业微信提供的命令行程序,所有操作通过执行 wecom-cli 命令完成。 概述 wecomcli-get-meeting 提供企业微信会议查询能力, 包含以下功能: 查询会议列表 - 按用户和时间范围查询会议 ID 列表 (限制: 当日及前后 30 天, 上限 100 个) 获取会议详情 - 通过会议 ID 查询完整会议信息 命令调用方式 执行指定命令: wecom-cli meeting < tool_name > '<json_params>' 命令详细说明 1. 查询会议列表 (list_user_meetings) 查询指定用户在时间范围内的会议 ID 列表. 执行命令 wecom-cli meeting list_user_meetings '{"begin_datetime": "2026-03-01 00:00", "end_datetime": "2026-03-31 23:59", "limit": 100}' 入参说明 参数 类型 必填 说明 begin_datetime string 否 查询起始时间, 格式: YYY...
|
2.4K |
| 7248 | hyperframes-read-first | heygen-com/hyperframes |
HyperFrames — read this first Start here for any HyperFrames task — especially with no project agent config ( CLAUDE.md / AGENTS.md / .cursorrules ) present. Capability map + video router below. Capability map — which skill for which intent You want to… Go to Make a video (from a URL, brief, topic, GitHub PR, existing footage, or a single element to animate) the video router below (§ Video routing) Author / edit an HTML composition — the data-* contract, clips, tracks, sub-compositions, variable...
|
2.4K |
| 7249 | wecomcli-get-todo-list | wecomteam/wecom-cli |
企业微信待办列表查询技能 wecom-cli 是企业微信提供的命令行程序,所有操作通过执行 wecom-cli 命令完成。 通过 wecom-cli 查询企业微信待办列表,支持按时间过滤和分页。 行为策略 查完列表必须查详情 : 本接口只返回待办 ID 和状态等概要信息,不包含待办的实际内容和分派人。对用户来说,没有内容的待办列表毫无用处——他们想知道的是"要做什么",而不是一串 ID。因此,每次调用 get_todo_list 拿到结果后,都要紧接着用返回的 todo_id 列表调用 wecomcli-get-todo-detail 获取完整详情(内容、分派人等),然后再向用户展示。这不是可选步骤,而是完成用户请求的必要环节。 分页未拉完时必须提醒用户 : 接口是分页的,不要求一次性拉完所有数据。但如果响应中 has_more 为 true ,说明后面还有待办没有返回——这时你在展示当前结果的同时,必须明确告诉用户"还有更多待办未显示,是否需要继续查看?"。用户可能不知道后面还有数据,如果你不说,他们会以为看到的就是全部,这会导致遗漏重要待办。这是一个容易被忽略但后果严重的点,请务必...
|
2.4K |
| 7250 | wecomcli-manage-smartsheet-schema | wecomteam/wecom-cli |
企业微信智能表格结构管理 wecom-cli 是企业微信提供的命令行程序,所有操作通过执行 wecom-cli 命令完成。 管理智能表格的子表和字段(列)结构。所有接口支持通过 docid 或 url 二选一定位文档。 调用方式 通过 wecom-cli 调用,品类为 doc : wecom-cli doc < tool_name > '<json_params>' 返回格式说明 所有接口返回 JSON 对象,包含以下公共字段: 字段 类型 说明 errcode integer 返回码, 0 表示成功,非 0 表示失败 errmsg string 错误信息,成功时为 "ok" 当 errcode 不为 0 时,说明接口调用失败,可重试 1 次;若仍失败,将 errcode 和 errmsg 展示给用户。 子表管理 smartsheet_get_sheet 查询文档中所有子表信息,返回 sheet_id、title、类型等。 wecom-cli doc smartsheet_get_sheet '{"docid": "DOCID"}' smartsheet_add_sheet 添加空子表...
|
2.4K |